@@ -9,9 +9,10 @@ use Regexp::Ethiopic::Amharic qw(:forms overload setForm);
 BEGIN
 {
 	use strict;
+	use warnings;
 	use vars qw( $VERSION %IMExpected %IMError %plosives $GRANULARITY $STYLE );
 
-	$VERSION = "0.12";
+	$VERSION = "0.13";
 
 	%plosives = (
 		ቅ => 'k',
@@ -474,6 +475,13 @@ None presently known.
 
 Daniel Yacob,  L<dyacob@cpan.org|mailto:dyacob@cpan.org>
 
+=head1 LICENSE AND COPYRIGHT
+
+Copyright (c) 2003-2025, Daniel Yacob C<< <dyacob@cpan.org> >>. All rights reserved.
+
+This module is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself. See L<perlartistic>.
+
 =head1 SEE ALSO
 
 =over
